Learn R Programming

textAnnotatoR (version 1.0.1)

concatenate_memos: Concatenate memo texts

Description

Combines existing and new memo texts with proper separators, handling empty memos appropriately.

Combines existing and new memo texts with proper separators, handling empty memos appropriately.

Usage

concatenate_memos(existing_memo, new_memo)

concatenate_memos(existing_memo, new_memo)

Value

Character string of combined memo text

Character string of combined memo text

Arguments

existing_memo

Character string containing current memo text

new_memo

Character string containing memo text to append