Learn R Programming

textAnnotatoR (version 1.0.1)

export_hierarchy: Export code hierarchy to JSON format

Description

Converts the code hierarchy tree structure into a JSON string representation that can be saved or transmitted while preserving all node properties and relationships.

Usage

export_hierarchy(node)

Value

JSON string representation of the hierarchy

Arguments

node

Root node of the hierarchy tree