Learn R Programming

textAnnotatoR (version 1.0.1)

generate_readable_color: Generate readable highlight color

Description

Generates a random color that provides good contrast with black text by ensuring the color is bright enough. Uses HSL color space to maintain good saturation while ensuring sufficient lightness.

Usage

generate_readable_color()

Arguments

Value

Character string containing a hex color code