Learn R Programming

textAnnotatoR (version 1.0.1)

getVolumes: Get available storage volumes on Windows

Description

Creates a closure that returns a named vector of available Windows drive letters and their corresponding paths. Checks for the existence of drives from A: to Z: (excluding C: which is handled separately).

Usage

getVolumes()

Arguments

Value

Function that returns named character vector of available drives