Learn R Programming

textAnnotatoR (version 1.0.1)

import_hierarchy: Import code hierarchy from JSON format

Description

Reconstructs a code hierarchy tree structure from its JSON string representation, restoring all node properties and relationships.

Usage

import_hierarchy(json_string)

Value

Node object representing the reconstructed hierarchy

Arguments

json_string

JSON string representation of the hierarchy