Learn R Programming

textAnnotatoR (version 1.0.1)

save_as_text: Save annotated text as plain text

Description

Creates a plain text file containing the annotated text with code markers.

Creates a plain text file containing the annotated text with code markers.

Usage

save_as_text(filename, rv)

save_as_text(filename, rv)

Value

Invisible NULL, called for side effect

Invisible NULL, called for side effect

Arguments

filename

Character string specifying output file path

rv

ReactiveValues object containing:

  • text: Original text content

  • annotations: Data frame of annotations