Learn R Programming

textAnnotatoR (version 1.0.1)

update_dark_colors: Update existing dark colors to readable ones

Description

Checks all existing code colors and replaces any that are too dark with more readable alternatives while trying to maintain color diversity.

Usage

update_dark_colors(rv)

Value

Updated ReactiveValues object

Arguments

rv

ReactiveValues object containing code colors