Analyzes how different coders overlap in their code applications by comparing the frequency and patterns of code co-occurrences.
compare_co_occurrences(overlaps_list)List containing:
overlap_variation: Numeric value indicating range of overlap counts
summary: Character string describing variation in overlapping pairs
List of overlap patterns from different coders, where each entry contains:
combinations: List containing frequency table of code co-occurrences