Combines existing and new memo texts with proper separators, handling empty memos appropriately.
Combines existing and new memo texts with proper separators, handling empty memos appropriately.
concatenate_memos(existing_memo, new_memo)concatenate_memos(existing_memo, new_memo)
Character string of combined memo text
Character string of combined memo text
Character string containing current memo text
Character string containing memo text to append