Learn R Programming

textAnnotatoR (version 1.0.1)

create_action: Create and manage undo/redo action

Description

Creates an action object for the undo/redo system, containing information about the type of action, the data involved, and how to reverse the action.

Creates an action object for the undo/redo system, containing information about the type of action, the data involved, and how to reverse the action.

Usage

create_action(type, data, reverse_data = NULL)

create_action(type, data, reverse_data = NULL)

Value

List containing:

  • type: Action type identifier

  • data: Action data

  • reverse_data: Data for reversing the action

  • timestamp: Time the action was created

List containing:

  • type: Action type identifier

  • data: Action data

  • reverse_data: Data for reversing the action

  • timestamp: Time the action was created

Arguments

type

Character string specifying the type of action

data

List containing the action data

reverse_data

Optional list containing data for reversing the action