Creates an action object for the undo/redo system, containing information about the type of action, the data involved, and how to reverse the action.
Creates an action object for the undo/redo system, containing information about the type of action, the data involved, and how to reverse the action.
create_action(type, data, reverse_data = NULL)create_action(type, data, reverse_data = NULL)
List containing:
type: Action type identifier
data: Action data
reverse_data: Data for reversing the action
timestamp: Time the action was created
List containing:
type: Action type identifier
data: Action data
reverse_data: Data for reversing the action
timestamp: Time the action was created
Character string specifying the type of action
List containing the action data
Optional list containing data for reversing the action