powered by
Converts the code hierarchy tree structure into a JSON string representation that can be saved or transmitted while preserving all node properties and relationships.
export_hierarchy(node)
JSON string representation of the hierarchy
Root node of the hierarchy tree