powered by
Checks all existing code colors and replaces any that are too dark with more readable alternatives while trying to maintain color diversity.
update_dark_colors(rv)
Updated ReactiveValues object
ReactiveValues object containing code colors